@@ -3,5 +3,5 @@ from .elasticsearch import (
     document_exists,
     index_to_elasticsearch,
     get_response_value,
-    fields_in_hits
+    fields_in_hits,
 )
